@@ -35,6 +35,7 @@ def test_robot_connect_success(monkeypatch: pytest.MonkeyPatch) -> None:
     robot = Robot()
     assert robot.connect("127.0.0.1") is True
     assert robot.namespace == "nest_2777af2b92e0fa78_798e8abd6e"
+    assert robot.last_error is None
 
 
 def test_robot_connect_failure(monkeypatch: pytest.MonkeyPatch) -> None:
@@ -46,3 +47,4 @@ def test_robot_connect_failure(monkeypatch: pytest.MonkeyPatch) -> None:
     robot = Robot()
     assert robot.connect("127.0.0.1") is False
     assert robot.namespace is None
+    assert robot.last_error == "URL error: boom"
